@@ -10,6 +10,7 @@ from typing import Any
 import async_timeout
 from aiohttp import ClientError, ClientSession
 
+from .const import TIMEOUT, URL
 from .exceptions import (
     EnedisException,
     HttpRequestError,
@@ -17,9 +18,6 @@ from .exceptions import (
     TimeoutExceededError,
 )
 
-URL = "https://myelectricaldata.fr"
-TIMEOUT = 30
-
 _LOGGER = logging.getLogger(__name__)
 
 
